Documentation
¶
Overview ¶
Code generated for package web by go-bindata DO NOT EDIT. (@generated) sources: dist/404.html dist/download.audio.html dist/download.html dist/download.image.html dist/download.markdown.html dist/download.sandbox.html dist/download.video.html dist/fonts/droid-sans-mono-400-normal-latin.woff2 dist/fonts/fonts.css dist/fonts/source-sans-pro-200-normal-cyrillic-ext.woff2 dist/fonts/source-sans-pro-200-normal-cyrillic.woff2 dist/fonts/source-sans-pro-200-normal-greek-ext.woff2 dist/fonts/source-sans-pro-200-normal-greek.woff2 dist/fonts/source-sans-pro-200-normal-latin-ext.woff2 dist/fonts/source-sans-pro-200-normal-latin.woff2 dist/fonts/source-sans-pro-200-normal-vietnamese.woff2 dist/fonts/source-sans-pro-300-normal-cyrillic-ext.woff2 dist/fonts/source-sans-pro-300-normal-cyrillic.woff2 dist/fonts/source-sans-pro-300-normal-greek-ext.woff2 dist/fonts/source-sans-pro-300-normal-greek.woff2 dist/fonts/source-sans-pro-300-normal-latin-ext.woff2 dist/fonts/source-sans-pro-300-normal-latin.woff2 dist/fonts/source-sans-pro-300-normal-vietnamese.woff2 dist/images/Logo-orange.png dist/images/bitcoin.png dist/images/reviews/dave.jpg dist/images/reviews/jacob.jpg dist/images/reviews/kareem.jpg dist/images/reviews/lars.jpg dist/images/reviews/pg.jpeg dist/includes/download-bottom.html dist/includes/download-delete.html dist/includes/download-footer.html dist/includes/download-head.html dist/includes/download-js.html dist/includes/download-navigation.html dist/includes/download-top.html dist/includes/footer.html dist/includes/ga.html dist/includes/head.html dist/includes/js.html dist/includes/navigation.html dist/index.html dist/scripts/main.js dist/scripts/vendor/modernizr.js dist/styles/main.css
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Prefix = "dist"
Functions ¶
func Asset ¶
Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.
func AssetDir ¶
AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:
data/
foo.txt
img/
a.png
b.png
then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.
func AssetInfo ¶
AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.
func MustAsset ¶
MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.
func RestoreAsset ¶
RestoreAsset restores an asset under the given directory
func RestoreAssets ¶
RestoreAssets restores an asset under the given directory recursively
Types ¶
This section is empty.